Struct access_protocol::instruction::create_bond::Params
source · pub struct Params {
pub buyer: Pubkey,
pub total_amount_sold: u64,
pub total_quote_amount: u64,
pub quote_mint: Pubkey,
pub seller_token_account: Pubkey,
pub unlock_start_date: i64,
pub unlock_period: i64,
pub unlock_amount: u64,
pub seller_index: u64,
}Expand description
The required parameters for the create_bond instruction
Fields
buyer: PubkeyUltimate buyer of the bond
total_amount_sold: u64Total amount of ACCESS tokens being sold
total_quote_amount: u64Total price of the bond
quote_mint: PubkeyMint of the token used to buy the bond
seller_token_account: PubkeyThe token account i.e where the sell proceeds go
unlock_start_date: i64The start date of the unlock
unlock_period: i64The time interval at which the tokens unlock
unlock_amount: u64The amount of tokens that unlock at each unlock_period
seller_index: u64Index of the seller in the array of authorized sellers